<?php

namespace agy;

/**
 * Admin Meta Class
 */
class AGY_Tax_Meta {

	/**
	 * Return instance of AGY_Tax_Meta
	 *
	 * @return void
	 */
	public static function get_instance() {
		new AGY_Tax_Meta();
	}

	/**
	 * Constructor for AGY_Tax_Meta.
	 */
	public function __construct() {
		if ( \agy_fs()->is_plan__premium_only( 'pro' ) ) {
			add_action( 'init', array( $this, 'register_blacklist_meta' ) );

			// For product cats.
			add_action( 'product_cat_add_form_fields', array( $this, 'add_form_field_term_blacklist' ) );
			add_action( 'product_cat_edit_form_fields', array( $this, 'edit_form_field_term_blacklist' ) );
			add_action( 'edit_product_cat', array( $this, 'save_term_blacklist' ) );
			add_action( 'create_product_cat', array( $this, 'save_term_blacklist' ) );
			add_filter( 'manage_edit-product_cat_columns', array( $this, 'edit_term_columns' ) );
			add_filter( 'manage_product_cat_custom_column', array( $this, 'manage_term_custom_column' ), 10, 3 );

			// For product tags.
			add_action( 'product_tag_add_form_fields', array( $this, 'add_form_field_term_blacklist' ) );
			add_action( 'product_tag_edit_form_fields', array( $this, 'edit_form_field_term_blacklist' ) );
			add_action( 'edit_product_tag', array( $this, 'save_term_blacklist' ) );
			add_action( 'create_product_tag', array( $this, 'save_term_blacklist' ) );
			add_filter( 'manage_edit-product_tag_columns', array( $this, 'edit_term_columns' ) );
			add_filter( 'manage_product_tag_custom_column', array( $this, 'manage_term_custom_column' ), 10, 3 );
		}
	}

	/**
	 * Register Meta for terms.
	 *
	 * @return void
	 */
	public function register_blacklist_meta() {
		if ( \agy_fs()->is_plan__premium_only( 'pro' ) ) {
			register_meta( 'term', 'blacklist', array() );
		}
	}

	/**
	 * New term meta fields.
	 *
	 * @return void
	 */
	public function add_form_field_term_blacklist() {
		if ( \agy_fs()->is_plan__premium_only( 'pro' ) ) {
			// whitelist or blacklist.
			$general_options = wp_parse_args( get_option( 'psag_options' ), AGY_Admin::get_defaults( 'psag_options' ) );
			$blacklist_label = __( '<b>Deactivate</b> Age Verification for this content.', 'content-warning-v2' );

			if ( isset( $general_options['psag_blacklist_to_whitelist'] ) && 'on' === $general_options['psag_blacklist_to_whitelist'] ) {
				$blacklist_label = __( '<b>Activate</b> Age Verification for this content.', 'content-warning-v2' );
			}
			?>
			<?php wp_nonce_field( basename( __FILE__ ), 'blacklist_nonce' ); ?>
			<div class="form-field term-meta-text-wrap">
				<label>
					<input type="checkbox" name="blacklist" id="blacklist" value="<?php echo $blacklist; ?>" <?php echo $checked; ?>>
					<?php echo $blacklist_label; ?>
				</label>
			</div>
			<?php
		}
	}

	/**
	 * Edit term meta fields
	 *
	 * @param object $term current term object.
	 * @return void
	 */
	public function edit_form_field_term_blacklist( $term ) {
		if ( \agy_fs()->is_plan__premium_only( 'pro' ) ) {
			$blacklist = get_term_meta( $term->term_id, 'blacklist', true );

			if ( empty( $blacklist ) ) {
				$checked = '';
			} else {
				$checked = 'checked="checked"';
			}

			// whitelist or blacklist.
			$general_options    = wp_parse_args( get_option( 'psag_options' ), AGY_Admin::get_defaults( 'psag_options' ) );
			$blacklist_label    = __( '<b>Deactivate</b> Age Verification for this content.', 'content-warning-v2' );
			$blacklist_headline = __( 'Blacklist', 'content-warning-v2' );

			if ( isset( $general_options['psag_blacklist_to_whitelist'] ) && 'on' === $general_options['psag_blacklist_to_whitelist'] ) {
				$blacklist_label    = __( '<b>Activate</b> Age Verification for this content.', 'content-warning-v2' );
				$blacklist_headline = __( 'Whitelist', 'content-warning-v2' );
			}
			?>
			<tr class="form-field term-meta-text-wrap">
				<th scope="row"><label for="term-meta-text"><?php echo esc_html( $blacklist_headline ) ?></label></th>
				<td>
					<?php wp_nonce_field( basename( __FILE__ ), 'blacklist_nonce' ); ?>
					<label>
						<input type="checkbox" name="blacklist" id="blacklist" value="<?php echo $blacklist; ?>" <?php echo $checked; ?>>
						<?php echo $blacklist_label; ?>
					</label>
				</td>
			</tr>
			<?php
		}
	}

	/**
	 * Save term object.
	 *
	 * @param int $term_id current term id.
	 * @return void
	 */
	public function save_term_blacklist( $term_id ) {
		if ( \agy_fs()->is_plan__premium_only( 'pro' ) ) {
			if ( ! isset( $_POST['blacklist_nonce'] ) || ! wp_verify_nonce( $_POST['blacklist_nonce'], basename( __FILE__ ) ) ) {
				return;
			}

			if ( isset( $_POST['blacklist'] ) ) {
				update_term_meta( $term_id, 'blacklist', true );
			} else {
				delete_term_meta( $term_id, 'blacklist' );
			}
		}
	}

	/**
	 * Modify admin columns for term.
	 *
	 * @param array $columns array of column names.
	 * @return array
	 */
	public function edit_term_columns( $columns ) {
		if ( \agy_fs()->is_plan__premium_only( 'pro' ) ) {
			// whitelist or blacklist.
			$general_options    = wp_parse_args( get_option( 'psag_options' ), AGY_Admin::get_defaults( 'psag_options' ) );
			$blacklist_headline = __( 'Blacklist', 'content-warning-v2' );

			if ( isset( $general_options['psag_blacklist_to_whitelist'] ) && 'on' === $general_options['psag_blacklist_to_whitelist'] ) {
				$blacklist_headline = __( 'Whitelist', 'content-warning-v2' );
			}

			$columns['blacklist'] = esc_html( $blacklist_headline );
			return $columns;
		}
	}


	/**
	 * Add content to column row.
	 *
	 * @param string $out the output.
	 * @param string $column the column.
	 * @param int    $term_id current term id.
	 * @return string
	 */
	public function manage_term_custom_column( $out, $column, $term_id ) {
		if ( \agy_fs()->is_plan__premium_only( 'pro' ) ) {
			if ( 'blacklist' === $column ) {
				$blacklist = get_term_meta( $term_id, 'blacklist', true );

				if ( empty( $blacklist ) ) {
					$value = 'off';
				} else {
					$value = 'on';
				}

				$out = sprintf( '<span class="term-meta-text-block" style="" >%s</div>', esc_attr( $value ) );
			}
			return $out;
		}
	}
}
