<?php

namespace agy;

/**
 * AGY_Sofort_Ident
 */
class AGY_Sofort_Ident {

	/**
	 * Constructor for AGY_Sofort_Ident
	 */
	public function __construct() {
		$woocommerce_settings = wp_parse_args( get_option( 'psag_woocommerce' ), AGY_Admin::get_defaults( 'psag_woocommerce' ) );
		$use_ident            = apply_filters( 'agy_use_sofort_ident', true );

		if ( isset( $woocommerce_settings['psag_woocommerce_activate_sofort_ident'] ) && 'on' === $woocommerce_settings['psag_woocommerce_activate_sofort_ident'] && $use_ident ) {
			add_action( 'woocommerce_review_order_before_submit', array( $this, 'add_identify_button' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'add_ident_assets' ) );
		}
	}

    public function add_ident_assets() {
	    wp_enqueue_script( 'agy-sofort-ident-js', AGY_URL . '/assets/public/agy-sofort-ident.js', array( 'jquery' ), AGY_VERSION, true );
    }

	/**
	 * Get an instance of AGY_Sofort_Ident
	 *
	 * @return void
	 */
	public static function get_instance() {
		new AGY_Sofort_Ident();
	}

	/**
	 * Disable checkout button if invalid age verification.
	 *
	 * @return string
	 */
	public static function check_verification() {
		$woocommerce_settings = wp_parse_args( get_option( 'psag_woocommerce' ), AGY_Admin::get_defaults( 'psag_woocommerce' ) );

		$block_checkout = 'no';

		if ( ! is_checkout() ) {
			return $block_checkout;
		}

		if ( empty( $woocommerce_settings['psag_woocommerce_activate_sofort_ident'] ) || 'off' === $woocommerce_settings['psag_woocommerce_activate_sofort_ident'] ) {
			return $block_checkout;
		}

		if ( ! empty( $woocommerce_settings['psag_woocommerce_sofort_ident_apply_to_blacklist'] ) && 'on' === $woocommerce_settings['psag_woocommerce_sofort_ident_apply_to_blacklist'] ) {
			$blacklisted_in_cart = AGY_WooCommerce_Blacklist::has_cart_blacklisted_products();

			if ( $blacklisted_in_cart ) {
				return 'yes';
			}
		}

		if ( empty( $_GET ) ) {
			$block_checkout = 'yes';
		}

		if ( isset( $_GET['agecheck_result'] ) && 'valid' !== $_GET['agecheck_result'] ) {
			$block_checkout = 'yes';
		}

		return $block_checkout;
	}

	/**
	 * Add verification button.
	 *
	 * @return void
	 */
	public function add_identify_button() {
		$woocommerce_options = wp_parse_args( get_option( 'psag_woocommerce' ), AGY_Admin::get_defaults( 'psag_woocommerce' ) );

		// Check cart option.
		if ( isset( $woocommerce_options['psag_woocommerce_sofort_ident_apply_to_blacklist'] ) && 'on' === $woocommerce_options['psag_woocommerce_sofort_ident_apply_to_blacklist'] ) {
			$blacklisted_in_cart = AGY_WooCommerce_Blacklist::has_cart_blacklisted_products();

			if ( $blacklisted_in_cart ) {
				?>
				<p>
					<?php
					$data      = array( $woocommerce_options['psag_woocommerce_sofort_ident_user_id'], $woocommerce_options['psag_woocommerce_sofort_ident_project_id'], '', '', '', '', '', '', '', '', 'DE', '', '', '', '', '', '', $woocommerce_options['psag_woocommerce_sofort_ident_project_password'] );
					$implode   = implode( '|', $data );
					$hash_mode = $woocommerce_options['psag_woocommerce_sofort_ident_hash_mode'];
					$hash      = hash( $hash_mode, $implode );

					?>
					<form method="post" novalidate action="https://www.sofort.com/payment/agecheck">
						<input name="account_country_id" type="hidden" value="DE"/>
						<input name="user_id" type="hidden" value="<?php echo esc_html( $woocommerce_options['psag_woocommerce_sofort_ident_user_id'] ); ?>"/>
						<input name="project_id" type="hidden" value="<?php echo esc_html( $woocommerce_options['psag_woocommerce_sofort_ident_project_id'] ); ?>"/>
						<input name="hash" type="hidden" value="<?php echo esc_html( $hash ); ?>"/>
						<input type="submit" id="verify-age" value="<?php esc_html_e( 'Verify your age', 'content-warning-v2' ); ?>"/>
					</form>
				</p>
				<?php
			}
		} else {
			?>
			<p>
				<?php
				$data      = array( $woocommerce_options['psag_woocommerce_sofort_ident_user_id'], $woocommerce_options['psag_woocommerce_sofort_ident_project_id'], '', '', '', '', '', '', '', '', 'DE', '', '', '', '', '', '', $woocommerce_options['psag_woocommerce_sofort_ident_project_password'] );
				$implode   = implode( '|', $data );
				$hash_mode = $woocommerce_options['psag_woocommerce_sofort_ident_hash_mode'];
				$hash      = hash( $hash_mode, $implode );

				?>
				<form method="post" novalidate action="https://www.sofort.com/payment/agecheck">
					<input name="account_country_id" type="hidden" value="DE"/>
					<input name="user_id" type="hidden" value="<?php echo esc_html( $woocommerce_options['psag_woocommerce_sofort_ident_user_id'] ); ?>"/>
					<input name="project_id" type="hidden" value="<?php echo esc_html( $woocommerce_options['psag_woocommerce_sofort_ident_project_id'] ); ?>"/>
					<input name="hash" type="hidden" value="<?php echo esc_html( $hash ); ?>"/>
					<input type="submit" id="verify-age" value="<?php esc_html_e( 'Verify your age', 'content-warning-v2' ); ?>"/>
				</form>
			</p>
			<?php
		}
	}
}
