<?php

namespace agy;

/**
 * Registration class
 */
class AGY_WooCommerce_Registration {
	/**
	 * Getter for instance
	 *
	 * @return void
	 */
	public static function get_instance() {
		new AGY_WooCommerce_Registration();
	}

	/**
	 * Constructor for registration class
	 */
	public function __construct() {
		$woocommerce_settings = wp_parse_args( get_option( 'psag_woocommerce' ), AGY_Admin::get_defaults( 'psag_woocommerce' ) );

		/* add field to registration */
		if ( isset( $woocommerce_settings['psag_woocommerce_age_verify_registration'] ) ) {
			if ( 'on' === $woocommerce_settings['psag_woocommerce_age_verify_registration'] ) {
				add_action( 'woocommerce_register_form', array(
					$this,
					'add_age_verification_field_registration'
				), 11 );
				add_filter( 'woocommerce_registration_errors', array(
					$this,
					'validate_age_verification_field_registration'
				), 10, 3 );
			}
		}
		if ( isset( $woocommerce_settings['psag_woocommerce_save_age'] ) && 'on' === $woocommerce_settings['psag_woocommerce_save_age'] ) {
			add_action( 'woocommerce_created_customer', array( $this, 'save_age_verification_field_registration' ) );
			add_action( 'woocommerce_thankyou', array( $this, 'save_age_verification_field_checkout' ) );

			/* add meta field to user admin page */
			add_action( 'show_user_profile', array( $this, 'add_age_verfication_field_to_admin_profile' ) );
			add_action( 'edit_user_profile', array( $this, 'add_age_verfication_field_to_admin_profile' ) );
			add_action( 'personal_options_update', array( $this, 'save_age_verfication_field_to_admin_profile' ) );
			add_action( 'edit_user_profile_update', array( $this, 'save_age_verfication_field_to_admin_profile' ) );
		}

		if ( isset( $woocommerce_settings['psag_woocommerce_age_verify_checkout'] ) && 'on' === $woocommerce_settings['psag_woocommerce_age_verify_checkout'] ) {
			/* add field to woocommerce checkout */
			add_action( 'woocommerce_review_order_before_submit', array(
				$this,
				'add_age_verification_field_checkout'
			), 9 );
			add_action( 'woocommerce_checkout_process', array( $this, 'validate_age_verification_field_checkout' ) );
		}
	}

	/**
	 * Add registration field
	 *
	 * @return void
	 */
	public function add_age_verification_field_registration() {

		$general_options     = wp_parse_args( get_option( 'psag_options' ), AGY_Admin::get_defaults( 'psag_options' ) );
		$woocommerce_options = wp_parse_args( get_option( 'psag_woocommerce' ), AGY_Admin::get_defaults( 'psag_woocommerce' ) );

		woocommerce_form_field( 'psag_age_verification', array(
			'type'        => 'checkbox',
			'class'       => array( 'form-row privacy' ),
			'label_class' => array( 'woocommerce-form__label woocommerce-form__label-for-checkbox checkbox' ),
			'input_class' => array( 'woocommerce-form__input woocommerce-form__input-checkbox input-checkbox' ),
			'required'    => true,
			'label'       => $woocommerce_options['psag_woocommerce_at_least_18'],
		) );
	}

	/**
	 * Validate registration field
	 *
	 * @param array $errors
	 * @param string $username
	 * @param string $email
	 *
	 * @return void
	 */
	public function validate_age_verification_field_registration( $errors, $username, $email ) {
		$general_options     = wp_parse_args( get_option( 'psag_options' ), AGY_Admin::get_defaults( 'psag_options' ) );
		$woocommerce_options = wp_parse_args( get_option( 'psag_woocommerce' ), AGY_Admin::get_defaults( 'psag_woocommerce' ) );

		if ( ! isset( $_POST['psag_age_verification'] ) ) {
			$errors->add( 'privacy_policy_reg_error', $woocommerce_options['psag_woocommerce_at_least_18_error'] );
		}

		return $errors;
	}

	/**
	 * Save registration field to user meta
	 *
	 * @param int $customer_id
	 *
	 * @return void
	 */
	public function save_age_verification_field_registration( $customer_id ) {
		if ( isset( $_POST['psag_age_verification'] ) ) {
			update_user_meta( $customer_id, 'psag_age_verification', sanitize_text_field( $_POST['psag_age_verification'] ) );
		}
	}

	/**
	 * Add registration field to admin profile
	 *
	 * @param object $user
	 *
	 * @return void
	 */
	public function add_age_verfication_field_to_admin_profile( $user ) {
		$general_options = wp_parse_args( get_option( 'psag_options' ), AGY_Admin::get_defaults( 'psag_options' ) );
		?>
        <h3><?php esc_html_e( 'Age Verification', 'content-warning-v2' ); ?></h3>
        <table class="form-table">
            <tr>
                <th><?php echo sprintf( __( 'The current user is at least %s years old.', 'content-warning-v2' ), esc_html( $general_options['psag_restrict_default_age'] ) ); ?></th>
                <td>
					<?php
					$current_age = get_user_meta( $user->ID, 'psag_age_verification', true );

					if ( empty( $current_age ) ) {
						$current_age = '';
					}

					woocommerce_form_field( 'psag_age_verification', array(
						'type'  => 'checkbox',
						'class' => array( 'input-checkbox' ),
					), $current_age );
					?>
                </td>
            </tr>
        </table>
		<?php
	}

	/**
	 * Save registration field to admin profile
	 *
	 * @param int $user_id
	 *
	 * @return void
	 */
	public function save_age_verfication_field_to_admin_profile( $user_id ) {

		if ( ! current_user_can( 'edit_user', $user_id ) ) {
			return false;
		}

		if ( isset( $_POST['psag_age_verification'] ) ) {
			update_user_meta( $user_id, 'psag_age_verification', sanitize_text_field( $_POST['psag_age_verification'] ) );
		} else {
			update_user_meta( $user_id, 'psag_age_verification', 0 );
		}
	}

	/**
	 * Add regristration field to checkout
	 *
	 * @return void
	 */
	public function add_age_verification_field_checkout() {
		$general_options     = wp_parse_args( get_option( 'psag_options' ), AGY_Admin::get_defaults( 'psag_options' ) );
		$woocommerce_options = wp_parse_args( get_option( 'psag_woocommerce' ), AGY_Admin::get_defaults( 'psag_woocommerce' ) );
		$blacklisted_in_cart = false;

		// Check cart option.
		if ( isset( $woocommerce_options['psag_woocommerce_apply_to_blacklist'] ) && ! empty( $woocommerce_options['psag_woocommerce_apply_to_blacklist'] ) && 'on' === $woocommerce_options['psag_woocommerce_apply_to_blacklist'] ) {
			$blacklisted_in_cart = AGY_WooCommerce_Blacklist::has_cart_blacklisted_products();

			if ( $blacklisted_in_cart ) {
				woocommerce_form_field( 'psag_age_verification', array(
					'type'        => 'checkbox',
					'class'       => array( 'form-row privacy' ),
					'label_class' => array( 'woocommerce-form__label woocommerce-form__label-for-checkbox checkbox' ),
					'input_class' => array( 'woocommerce-form__input woocommerce-form__input-checkbox input-checkbox' ),
					'required'    => true,
					'label'       => $woocommerce_options['psag_woocommerce_at_least_18'],
				) );
			}
		} else {
			woocommerce_form_field( 'psag_age_verification', array(
				'type'        => 'checkbox',
				'class'       => array( 'form-row privacy' ),
				'label_class' => array( 'woocommerce-form__label woocommerce-form__label-for-checkbox checkbox' ),
				'input_class' => array( 'woocommerce-form__input woocommerce-form__input-checkbox input-checkbox' ),
				'required'    => true,
				'label'       => $woocommerce_options['psag_woocommerce_at_least_18'],
			) );
		}
	}

	/**
	 * Validate checkout field
	 *
	 * @return void
	 */
	public function validate_age_verification_field_checkout() {
		$general_options     = wp_parse_args( get_option( 'psag_options' ), AGY_Admin::get_defaults( 'psag_options' ) );
		$woocommerce_options = wp_parse_args( get_option( 'psag_woocommerce' ), AGY_Admin::get_defaults( 'psag_woocommerce' ) );
		$blacklisted_in_cart = false;

		// Check cart option.
		if ( isset( $woocommerce_options['psag_woocommerce_apply_to_blacklist'] ) && ! empty( $woocommerce_options['psag_woocommerce_apply_to_blacklist'] ) && 'on' === $woocommerce_options['psag_woocommerce_apply_to_blacklist'] ) {
			$blacklisted_in_cart = AGY_WooCommerce_Blacklist::has_cart_blacklisted_products();

			if ( $blacklisted_in_cart ) {
				if ( ! isset( $_POST['psag_age_verification'] ) ) {
					wc_add_notice( $woocommerce_options['psag_woocommerce_at_least_18_error'], 'error' );
				}
			}
		} else {
			if ( ! isset( $_POST['psag_age_verification'] ) ) {
				wc_add_notice( $woocommerce_options['psag_woocommerce_at_least_18_error'], 'error' );
			}
		}
	}

	/**
	 * Save checkout field to user
	 *
	 * @param int $order_id
	 *
	 * @return void
	 */
	public function save_age_verification_field_checkout( $order_id ) {
		$order   = wc_get_order( $order_id );
		$user_id = $order->get_user_id();

		update_user_meta( $user_id, 'psag_age_verification', 1 );
	}
}
